# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_responses.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi import basic_responses_pb2 as t2iapi_dot_basic__responses__pb2
from t2iapi import response_types_pb2 as t2iapi_dot_response__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$t2iapi/metric/metric_responses.proto\x12\rt2iapi.metric\x1a\x1ct2iapi/basic_responses.proto\x1a\x1bt2iapi/response_types.proto\"R\n\x1aSetOverOrUnderflowResponse\x12%\n\x06status\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\r\n\x05value\x18\x02 \x01(\t\"R\n\x17\x43\x61librateMetricResponse\x12\'\n\x08response\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\x0e\n\x06values\x18\x02 \x03(\t\"\x88\x01\n\x13MetricValueResponse\x12%\n\x06result\x18\x01 \x01(\x0b\x32\x15.t2iapi.BasicResponse\x12\r\n\x05value\x18\x02 \x01(\t\x12\x12\n\nstep_width\x18\x03 \x01(\t\x12\'\n\x04unit\x18\x04 \x01(\x0b\x32\x19.t2iapi.PartialCodedValueB4\n!com.draeger.medical.t2iapi.metricB\x0fMetricResponsesb\x06proto3')



_SETOVERORUNDERFLOWRESPONSE = DESCRIPTOR.message_types_by_name['SetOverOrUnderflowResponse']
_CALIBRATEMETRICRESPONSE = DESCRIPTOR.message_types_by_name['CalibrateMetricResponse']
_METRICVALUERESPONSE = DESCRIPTOR.message_types_by_name['MetricValueResponse']
SetOverOrUnderflowResponse = _reflection.GeneratedProtocolMessageType('SetOverOrUnderflowResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETOVERORUNDERFLOWRESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetOverOrUnderflowResponse)
  })
_sym_db.RegisterMessage(SetOverOrUnderflowResponse)

CalibrateMetricResponse = _reflection.GeneratedProtocolMessageType('CalibrateMetricResponse', (_message.Message,), {
  'DESCRIPTOR' : _CALIBRATEMETRICRESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.CalibrateMetricResponse)
  })
_sym_db.RegisterMessage(CalibrateMetricResponse)

MetricValueResponse = _reflection.GeneratedProtocolMessageType('MetricValueResponse', (_message.Message,), {
  'DESCRIPTOR' : _METRICVALUERESPONSE,
  '__module__' : 't2iapi.metric.metric_responses_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.MetricValueResponse)
  })
_sym_db.RegisterMessage(MetricValueResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\017MetricResponses'
  _SETOVERORUNDERFLOWRESPONSE._serialized_start=114
  _SETOVERORUNDERFLOWRESPONSE._serialized_end=196
  _CALIBRATEMETRICRESPONSE._serialized_start=198
  _CALIBRATEMETRICRESPONSE._serialized_end=280
  _METRICVALUERESPONSE._serialized_start=283
  _METRICVALUERESPONSE._serialized_end=419
# @@protoc_insertion_point(module_scope)
