# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/device/device_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.device import types_pb2 as t2iapi_dot_device_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/device/device_requests.proto\x12\rt2iapi.device\x1a\x19t2iapi/device/types.proto\"A\n\x14TriggerReportRequest\x12)\n\x06report\x18\x01 \x01(\x0e\x32\x19.t2iapi.device.ReportType\"N\n\x1dSetDeviceOperatingModeRequest\x12-\n\x04mode\x18\x01 \x01(\x0e\x32\x1f.t2iapi.device.MdsOperatingMode\"U\n\x1fGenerateElementsInStatesRequest\x12\x32\n\rrelative_path\x18\x01 \x03(\x0b\x32\x1b.t2iapi.device.ExpandedName\"&\n\x12SetLanguageRequest\x12\x10\n\x08language\x18\x01 \x01(\t\"7\n\x1b\x43hangeMdibSequenceIdRequest\x12\x18\n\x10\x64\x65scriptive_name\x18\x01 \x01(\tB3\n!com.draeger.medical.t2iapi.deviceB\x0e\x44\x65viceRequestsb\x06proto3')



_TRIGGERREPORTREQUEST = DESCRIPTOR.message_types_by_name['TriggerReportRequest']
_SETDEVICEOPERATINGMODEREQUEST = DESCRIPTOR.message_types_by_name['SetDeviceOperatingModeRequest']
_GENERATEELEMENTSINSTATESREQUEST = DESCRIPTOR.message_types_by_name['GenerateElementsInStatesRequest']
_SETLANGUAGEREQUEST = DESCRIPTOR.message_types_by_name['SetLanguageRequest']
_CHANGEMDIBSEQUENCEIDREQUEST = DESCRIPTOR.message_types_by_name['ChangeMdibSequenceIdRequest']
TriggerReportRequest = _reflection.GeneratedProtocolMessageType('TriggerReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERREPORTREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.TriggerReportRequest)
  })
_sym_db.RegisterMessage(TriggerReportRequest)

SetDeviceOperatingModeRequest = _reflection.GeneratedProtocolMessageType('SetDeviceOperatingModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICEOPERATINGMODEREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.SetDeviceOperatingModeRequest)
  })
_sym_db.RegisterMessage(SetDeviceOperatingModeRequest)

GenerateElementsInStatesRequest = _reflection.GeneratedProtocolMessageType('GenerateElementsInStatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEELEMENTSINSTATESREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.GenerateElementsInStatesRequest)
  })
_sym_db.RegisterMessage(GenerateElementsInStatesRequest)

SetLanguageRequest = _reflection.GeneratedProtocolMessageType('SetLanguageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLANGUAGEREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.SetLanguageRequest)
  })
_sym_db.RegisterMessage(SetLanguageRequest)

ChangeMdibSequenceIdRequest = _reflection.GeneratedProtocolMessageType('ChangeMdibSequenceIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEMDIBSEQUENCEIDREQUEST,
  '__module__' : 't2iapi.device.device_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.device.ChangeMdibSequenceIdRequest)
  })
_sym_db.RegisterMessage(ChangeMdibSequenceIdRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.deviceB\016DeviceRequests'
  _TRIGGERREPORTREQUEST._serialized_start=81
  _TRIGGERREPORTREQUEST._serialized_end=146
  _SETDEVICEOPERATINGMODEREQUEST._serialized_start=148
  _SETDEVICEOPERATINGMODEREQUEST._serialized_end=226
  _GENERATEELEMENTSINSTATESREQUEST._serialized_start=228
  _GENERATEELEMENTSINSTATESREQUEST._serialized_end=313
  _SETLANGUAGEREQUEST._serialized_start=315
  _SETLANGUAGEREQUEST._serialized_end=353
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_start=355
  _CHANGEMDIBSEQUENCEIDREQUEST._serialized_end=410
# @@protoc_insertion_point(module_scope)
