# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: t2iapi/metric/metric_requests.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from t2iapi.metric import types_pb2 as t2iapi_dot_metric_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#t2iapi/metric/metric_requests.proto\x12\rt2iapi.metric\x1a\x19t2iapi/metric/types.proto\"9\n\x12SetOverflowRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x13\n\x0bupper_bound\x18\x02 \x01(\t\":\n\x13SetUnderflowRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x13\n\x0blower_bound\x18\x02 \x01(\t\"g\n\x1fSetMetricQualityValidityRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x34\n\x08validity\x18\x02 \x01(\x0e\x32\".t2iapi.metric.MeasurementValidity\"d\n%SetMetricValuesWithQualityModeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x04mode\x18\x02 \x01(\x0e\x32\x1d.t2iapi.metric.GenerationMode\"M\n\x1dSetMetricValuesInRangeRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\r\n\x05lower\x18\x02 \x01(\t\x12\r\n\x05upper\x18\x03 \x01(\t\"u\n ChangeOperationModeStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12\x41\n\x15operation_mode_status\x18\x02 \x01(\x0e\x32\".t2iapi.metric.OperationModeStatus\"U\n\x16SetMetricStatusRequest\x12\x0e\n\x06handle\x18\x01 \x01(\t\x12+\n\x06status\x18\x02 \x01(\x0e\x32\x1b.t2iapi.metric.MetricStatusB3\n!com.draeger.medical.t2iapi.metricB\x0eMetricRequestsb\x06proto3')



_SETOVERFLOWREQUEST = DESCRIPTOR.message_types_by_name['SetOverflowRequest']
_SETUNDERFLOWREQUEST = DESCRIPTOR.message_types_by_name['SetUnderflowRequest']
_SETMETRICQUALITYVALIDITYREQUEST = DESCRIPTOR.message_types_by_name['SetMetricQualityValidityRequest']
_SETMETRICVALUESWITHQUALITYMODEREQUEST = DESCRIPTOR.message_types_by_name['SetMetricValuesWithQualityModeRequest']
_SETMETRICVALUESINRANGEREQUEST = DESCRIPTOR.message_types_by_name['SetMetricValuesInRangeRequest']
_CHANGEOPERATIONMODESTATUSREQUEST = DESCRIPTOR.message_types_by_name['ChangeOperationModeStatusRequest']
_SETMETRICSTATUSREQUEST = DESCRIPTOR.message_types_by_name['SetMetricStatusRequest']
SetOverflowRequest = _reflection.GeneratedProtocolMessageType('SetOverflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETOVERFLOWREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetOverflowRequest)
  })
_sym_db.RegisterMessage(SetOverflowRequest)

SetUnderflowRequest = _reflection.GeneratedProtocolMessageType('SetUnderflowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETUNDERFLOWREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetUnderflowRequest)
  })
_sym_db.RegisterMessage(SetUnderflowRequest)

SetMetricQualityValidityRequest = _reflection.GeneratedProtocolMessageType('SetMetricQualityValidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICQUALITYVALIDITYREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricQualityValidityRequest)
  })
_sym_db.RegisterMessage(SetMetricQualityValidityRequest)

SetMetricValuesWithQualityModeRequest = _reflection.GeneratedProtocolMessageType('SetMetricValuesWithQualityModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICVALUESWITHQUALITYMODEREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricValuesWithQualityModeRequest)
  })
_sym_db.RegisterMessage(SetMetricValuesWithQualityModeRequest)

SetMetricValuesInRangeRequest = _reflection.GeneratedProtocolMessageType('SetMetricValuesInRangeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICVALUESINRANGEREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricValuesInRangeRequest)
  })
_sym_db.RegisterMessage(SetMetricValuesInRangeRequest)

ChangeOperationModeStatusRequest = _reflection.GeneratedProtocolMessageType('ChangeOperationModeStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEOPERATIONMODESTATUSREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.ChangeOperationModeStatusRequest)
  })
_sym_db.RegisterMessage(ChangeOperationModeStatusRequest)

SetMetricStatusRequest = _reflection.GeneratedProtocolMessageType('SetMetricStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETMETRICSTATUSREQUEST,
  '__module__' : 't2iapi.metric.metric_requests_pb2'
  # @@protoc_insertion_point(class_scope:t2iapi.metric.SetMetricStatusRequest)
  })
_sym_db.RegisterMessage(SetMetricStatusRequest)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.draeger.medical.t2iapi.metricB\016MetricRequests'
  _SETOVERFLOWREQUEST._serialized_start=81
  _SETOVERFLOWREQUEST._serialized_end=138
  _SETUNDERFLOWREQUEST._serialized_start=140
  _SETUNDERFLOWREQUEST._serialized_end=198
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_start=200
  _SETMETRICQUALITYVALIDITYREQUEST._serialized_end=303
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_start=305
  _SETMETRICVALUESWITHQUALITYMODEREQUEST._serialized_end=405
  _SETMETRICVALUESINRANGEREQUEST._serialized_start=407
  _SETMETRICVALUESINRANGEREQUEST._serialized_end=484
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_start=486
  _CHANGEOPERATIONMODESTATUSREQUEST._serialized_end=603
  _SETMETRICSTATUSREQUEST._serialized_start=605
  _SETMETRICSTATUSREQUEST._serialized_end=690
# @@protoc_insertion_point(module_scope)
